# JavaScript Example: Managing Static Wallets

This example shows how to manage static wallets using JavaScript with the fetch API.

## Creating a Static Wallet

```javascript
/**
 * Sphere API - Create Static Wallet Example
 */

// API credentials
const merchantId = 'your_merchant_id';
const apiKey = 'your_api_key';

// API endpoint
const apiUrl = 'https://api.coinssend.com/v1/wallet-address';

// Wallet data
const walletData = {
  'network': 'tron',
  'coin': 'usdt',
  'label': 'USDT Payment Address',
  'webhook_url': 'https://example.com/webhook'
};

// Generate signature
const jsonData = JSON.stringify(walletData);
const base64Data = btoa(jsonData);
const signature = md5(base64Data + apiKey); // You'll need an MD5 library

// Make the API request
fetch(apiUrl, {
  method: 'POST',
  headers: {
    'Content-Type': 'application/json',
    'Merchant': merchantId,
    'Sign': signature
  },
  body: jsonData
})
.then(response => response.json())
.then(data => {
  if (data.status === 'success') {
    console.log("Wallet address created successfully!");
    console.log("Address: " + data.data.address);
  } else {
    console.error("Error: " + data.error.message);
  }
})
.catch(error => {
  console.error("Request failed: " + error);
});

/**
 * Simple MD5 function for browser environments
 * Note: For production, use a proper crypto library
 */
function md5(string) {
  // In a real implementation, use a proper MD5 library
  // This is just a placeholder
  return CryptoJS.MD5(string).toString();
}
```


## Using with Axios

For a more modern approach using Axios:

```javascript
// Install axios: npm install axios
import axios from 'axios';
import md5 from 'md5'; // Install md5: npm install md5

// API credentials
const merchantId = 'your_merchant_id';
const apiKey = 'your_api_key';

// Create HTTP client
const client = axios.create({
  baseURL: 'https://api.coinssend.com/v1/',
  headers: {
    'Content-Type': 'application/json',
    'Merchant': merchantId
  }
});

// Function to create a static wallet
async function createStaticWallet(network, coin, label, webhookUrl = null) {
  // Wallet data
  const walletData = {
    network,
    coin,
    label
  };
  
  // Add webhook URL if provided
  if (webhookUrl) {
    walletData.webhook_url = webhookUrl;
  }
  
  // Generate signature
  const jsonData = JSON.stringify(walletData);
  const base64Data = Buffer.from(jsonData).toString('base64');
  const signature = md5(base64Data + apiKey);
  
  try {
    const response = await client.post('wallet-address', walletData, {
      headers: {
        'Sign': signature
      }
    });
    
    return response.data;
  } catch (error) {
    if (error.response) {
      throw new Error(error.response.data.error?.message || 'API Error');
    } else {
      throw new Error(error.message || 'Connection Error');
    }
  }
}

// Usage examples
async function examples() {
  try {
    // Create a new USDT wallet on TRON network
    const newWallet = await createStaticWallet('tron', 'usdt', 'My USDT Wallet');
    console.log('New wallet created:', newWallet.data.address);
    
  } catch (error) {
    console.error('Error:', error.message);
  }
}

examples();
```

## Reusable API Client Class

For multiple API calls, create a reusable client class:

```javascript
class SphereApiClient {
  constructor(merchantId, apiKey, baseUrl = 'https://api.coinssend.com/v1/') {
    this.merchantId = merchantId;
    this.apiKey = apiKey;
    this.baseUrl = baseUrl;
  }
  
  // Static Wallet Methods
  async createStaticWallet(network, coin, label, webhookUrl = null) {
    const data = {
      network,
      coin,
      label
    };
    
    if (webhookUrl) {
      data.webhook_url = webhookUrl;
    }
    
    return this.sendRequest('POST', 'wallet-address', data);
  }
  
  
  // Generic request method
  async sendRequest(method, endpoint, data = null) {
    const url = this.baseUrl + endpoint;
    const jsonData = data ? JSON.stringify(data) : '';
    const base64Data = data ? btoa(jsonData) : '';
    const signature = data ? md5(base64Data + this.apiKey) : md5(this.apiKey);
    
    const headers = {
      'Content-Type': 'application/json',
      'Merchant': this.merchantId,
      'Sign': signature
    };
    
    const options = {
      method: method,
      headers: headers
    };
    
    if (jsonData) {
      options.body = jsonData;
    }
    
    try {
      const response = await fetch(url, options);
      const responseData = await response.json();
      
      if (response.ok) {
        return responseData;
      } else {
        throw new Error(responseData.error?.message || 'API Error');
      }
    } catch (error) {
      throw error;
    }
  }
}

// Usage
async function main() {
  try {
    const client = new SphereApiClient('your_merchant_id', 'your_api_key');
    
    // Create a new wallet
    const createResult = await client.createStaticWallet('tron', 'usdt', 'USDT Payments');
    console.log('Wallet created:', createResult.data.address);
    
  } catch (error) {
    console.error('Error:', error.message);
  }
}

main();
```